pygeodesy.ltpTuples.ChLV9Tuple

Package pygeodesy :: Module ltpTuples :: Class ChLV9Tuple |
[frames] | no frames]

# Class ChLV9Tuple

       object --+
                |
            tuple --+
                    |
       object --+   |
                |   |
     named._Named --+
                    |
    named._NamedTuple --+
                        |
              Local9Tuple --+
                            |
                           ChLV9Tuple

9-Tuple `(Y, X, h_, lat, lon, height, ltp, ecef, M)` with unfalsed Swiss (Y, X, h_) coordinates and height, all in `meter`, `ltp` either a ChLV, ChLVa or ChLVe instance and `ecef` (EcefKarney at Bern, Ch), otherwise like Local9Tuple.

Instance Methods
Inherited from `Local9Tuple`: `toAer`, `toCartesian`, `toEnu`, `toLatLon`, `toNed`, `toXyz` Inherited from `named._NamedTuple`: `__delattr__`, `__getattr__`, `__hash__`, `__repr__`, `__setattr__`, `__str__`, `dup`, `items`, `iteritems`, `iterunits`, `reUnit`, `toRepr`, `toStr`, `toUnits`, `units` Inherited from `tuple`: `__add__`, `__contains__`, `__eq__`, `__ge__`, `__getattribute__`, `__getitem__`, `__getnewargs__`, `__getslice__`, `__gt__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__mul__`, `__ne__`, `__rmul__`, `count`, `index` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__init__`, `__reduce__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Static Methods
Inherited from `named._NamedTuple`: `__new__`

Properties
| E_LV95 Get the falsed Swiss E_LV95 easting (`meter`).
| EN2_LV95 Get the falsed Swiss (E_LV95, N_LV95) easting and northing (ChLVEN2Tuple).
| h_LV03 Get the Swiss h_ height (`meter`).
| h_LV95 Get the Swiss h_ height (`meter`).
| isChLV Is this a ChLV-generated ChLV9Tuple?.
| isChLVa Is this a ChLVa-generated ChLV9Tuple?.
| isChLVe Is this a ChLVe-generated ChLV9Tuple?.
| N_LV95 Get the falsed Swiss N_LV95 northing (`meter`).
| x Get the local x, Swiss Y easting (`meter`).
| x_LV03 Get the falsed Swiss x_LV03 northing (`meter`).
| y Get the local y, Swiss X northing (`meter`).
| y_LV03 Get the falsed Swisss y_LV03 easting (`meter`).
| YX Get the unfalsed easting and northing (ChLVYX2Tuple).
| yx2_LV03 Get the falsed Swiss (y_LV03, x_LV03) easting and northing (ChLVyx2Tuple).
| z Get the local z, Swiss h_ height (`meter`).
Inherited from `Local9Tuple`: `azimuth`, `down`, `east`, `elevation`, `groundrange`, `lam`, `latlon`, `latlonheight`, `north`, `phi`, `philam`, `philamheight`, `slantrange`, `up`, `xyz`, `xyzLocal` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Property Details

### E_LV95 Get the falsed Swiss E_LV95 easting (`meter`). Get method: E_LV95(self) - Get the falsed Swiss E_LV95 easting (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### EN2_LV95 Get the falsed Swiss (E_LV95, N_LV95) easting and northing (ChLVEN2Tuple). Get method: EN2_LV95(self) - Get the falsed Swiss (E_LV95, N_LV95) easting and northing (ChLVEN2Tuple). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### h_LV03 Get the Swiss h_ height (`meter`). Get method: h_LV03(self) - Get the Swiss h_ height (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### h_LV95 Get the Swiss h_ height (`meter`). Get method: h_LV95(self) - Get the Swiss h_ height (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### isChLV Is this a ChLV-generated ChLV9Tuple?. Get method: isChLV(self) - Is this a ChLV-generated ChLV9Tuple?. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### isChLVa Is this a ChLVa-generated ChLV9Tuple?. Get method: isChLVa(self) - Is this a ChLVa-generated ChLV9Tuple?. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### isChLVe Is this a ChLVe-generated ChLV9Tuple?. Get method: isChLVe(self) - Is this a ChLVe-generated ChLV9Tuple?. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### N_LV95 Get the falsed Swiss N_LV95 northing (`meter`). Get method: N_LV95(self) - Get the falsed Swiss N_LV95 northing (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### x Get the local x, Swiss Y easting (`meter`). Get method: x(self) - Get the local x, Swiss Y easting (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### x_LV03 Get the falsed Swiss x_LV03 northing (`meter`). Get method: x_LV03(self) - Get the falsed Swiss x_LV03 northing (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### y Get the local y, Swiss X northing (`meter`). Get method: y(self) - Get the local y, Swiss X northing (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### y_LV03 Get the falsed Swisss y_LV03 easting (`meter`). Get method: y_LV03(self) - Get the falsed Swisss y_LV03 easting (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### YX Get the unfalsed easting and northing (ChLVYX2Tuple). Get method: YX(self) - Get the unfalsed easting and northing (ChLVYX2Tuple). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### yx2_LV03 Get the falsed Swiss (y_LV03, x_LV03) easting and northing (ChLVyx2Tuple). Get method: yx2_LV03(self) - Get the falsed Swiss (y_LV03, x_LV03) easting and northing (ChLVyx2Tuple). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### z Get the local z, Swiss h_ height (`meter`). Get method: z(self) - Get the local z, Swiss h_ height (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.